@@ -1,14 +1,14 @@
 import os
 import unittest
 from tpv.rules import gateway
-from . import mock_galaxy
+from tpv.core.test import mock_galaxy
 
 
 class TestParamsSpecific(unittest.TestCase):
 
     @staticmethod
     def _map_to_destination(tool, user):
-        galaxy_app = mock_galaxy.App()
+        galaxy_app = mock_galaxy.App(job_conf=os.path.join(os.path.dirname(__file__), 'fixtures/job_conf.yml'))
         job = mock_galaxy.Job()
         tpv_config = os.path.join(os.path.dirname(__file__), 'fixtures/mapping-params-specific.yml')
         gateway.ACTIVE_DESTINATION_MAPPER = None
